pub enum Level {
SafeToAutomate,
DraftOnly,
InternalTaskOnly,
ManagerApprovalRequired,
NeverAutomate,
}Expand description
Automation authority level that says whether a workflow may run, draft, create internal tasks, or require approval.
Variants
SafeToAutomate
Safe to automate outcome in the automation authority or human-review policy.
DraftOnly
Draft only outcome in the automation authority or human-review policy.
InternalTaskOnly
Internal task only outcome in the automation authority or human-review policy.
ManagerApprovalRequired
Manager approval required outcome in the automation authority or human-review policy.
NeverAutomate
Never automate outcome in the automation authority or human-review policy.