pub struct Rule {
pub workflow: WorkflowName,
pub level: Level,
pub rationale: Rationale,
}Expand description
Automation policy rule tying a workflow name to an authority level and rationale.
Fields
workflow: WorkflowNamePolicy input workflow used to explain or enforce an automation gate.
level: LevelPolicy input level used to explain or enforce an automation gate.
rationale: RationalePolicy input rationale used to explain or enforce an automation gate.